@@ -23,6 +23,6 @@ scale_fill_etopo <- function(...) {
   ggplot2::scale_fill_gradientn(colours=etopo$colours, values=etopo$altitudes01, limits=range(etopo$altitudes), ...)
 }
 
-scale_colour_etopo <- function(...) {
+scale_color_etopo <- function(...) {
   ggplot2::scale_colour_gradientn(colours=etopo$colours, values=etopo$altitudes01, limits=range(etopo$altitudes), ...)
 }
